% File: figure13.m
% Author: Sarah Chen 
% Nov. 2007
% Function: Plot Figure 13 in "Decentralized Cognitive MAC for Opportunistic Spectrum 
%           Access in Ad Hoc Networks: A POMDP Framework"
clear; close;
numberOfChannels = 3;
T = 30;
time = [1:6,8,10:5:T];

%%%% the upper figure %%%%
channelBandwidth = 1;
prob0to1 = 0.2;
prob1to1 = 0.8;
avgRewardOptimal = optimalSensing(numberOfChannels, channelBandwidth, prob0to1, prob1to1, time, 'fig13a');
avgRewardGreedy = greedySensing(numberOfChannels, channelBandwidth, prob0to1, prob1to1, T);
avgRewardRandom = randomSensing(numberOfChannels, channelBandwidth, prob0to1, prob1to1, T);

figure(1); subplot(2,1,1);
plot([1:6,8,10:5:T], avgRewardOptimal, 1:T, avgRewardGreedy, '+:', 1:T, avgRewardRandom, '-.');
legend('Optimal', 'Greedy', 'Random');
xlabel('T');
ylabel('Throughput (bits per slot)');


%%%% the lower figure %%%%
channelBandwidth = [3/4, 1, 3/2];
prob0to1 = [0.8, 0.6, 0.4];
prob1to1 = [0.6, 0.4, 0.2];
avgRewardOptimal = optimalSensing(numberOfChannels, channelBandwidth, prob0to1, prob1to1, time, 'fig13b');
avgRewardGreedy = greedySensing(numberOfChannels, channelBandwidth, prob0to1, prob1to1, T);
avgRewardRandom = randomSensing(numberOfChannels, channelBandwidth, prob0to1, prob1to1, T);

figure(1); subplot(2,1,2);
plot(time, avgRewardOptimal, 1:T, avgRewardGreedy, '+:', 1:T, avgRewardRandom, '-.');
legend('Optimal', 'Greedy', 'Random');
xlabel('T');
ylabel('Throughput (bits per slot)');

saveas(gcf, 'figure13', 'fig');