% File: figure14.m
% Author: Sarah Chen 
% Nov. 2007
% Function: Plot Figure 14 in "Decentralized Cognitive MAC for Opportunistic Spectrum 
%           Access in Ad Hoc Networks: A POMDP Framework"
clear; close;
T = 30; % number of slots
numberOfChannels = 3; 
prob0to1 = 0.4 * ones(1, numberOfChannels);
prob1to1 = 0.5 * ones(1, numberOfChannels);
channelBandwidth = ones(1, numberOfChannels); % bandwidth of each channel
collisionProb = 0 : 0.05 : 0.55;
for i = 1 : length(collisionProb)
    [avgRewardGreedy(i), avgSeGreedy(i)] = greedySensingImperfect(numberOfChannels, channelBandwidth, ...
        prob0to1, prob1to1, T, collisionProb(i));
end

avgRewardOptimal = optimalSensing(numberOfChannels, channelBandwidth, prob0to1, prob1to1, T, 'fig14');
channelIdleProb = prob0to1 ./ (1 + prob0to1 - prob1to1);
avgSeOptimal = (avgRewardOptimal(end) + sum( 1 - channelIdleProb )) / numberOfChannels ;

figure(1); subplot(2,1,1);
plot(collisionProb, ones(1,length(collisionProb)) * avgRewardOptimal(end) , '-', ...
    collisionProb, avgRewardGreedy,'-o');
legend('Optimal', 'Greedy');
xlabel('Prescribed collision probability');
ylabel('Throughput (bits/Hz)');


subplot(2,1,2);
plot(collisionProb, ones(1,length(collisionProb)) * avgSeOptimal, '-',...
    collisionProb, avgSeGreedy,'-o');
legend('Optimal', 'Greedy');
xlabel('Prescribed collision probability');
ylabel('Spectrum efficiency (bits/slot/Hz)');

saveas(gcf, 'figure14', 'fig');