function pomdpInputFile(alpha, beta, BW, filename)
% File: pomdpInputFile.m
% Author: Sarah Chen 
% Nov. 2007
% Function: Generate the required input file for pomdp-solve.c 
%           (OSA with perfect sensing under independent channels)
% Inputs:  alpha, beta, B are 1xN row vectors (N: number of channels) 
%          alpha(i) = Pr {channel i transits from '0' to '1'};
%          beta(i) = Pr {channel i transits from '1' to '1'};
%          BW(i) = bandwidth of channel i;
%          filename: the desired pomdp-solve input file (xxx.POMDP)

num_ch = length(BW);
num_st = 2^num_ch;

fid = fopen(filename,'w');
fprintf(fid,'discount: 1.0\n');
fprintf(fid,'values: reward\n');
fprintf(fid,'states: %d\n', num_st);
fprintf(fid,'actions: %d\n', num_ch);
fprintf(fid,'observations: 2\n\n');

% channel state transition 
% format T : <action> : <start-state> : <end-state> %f
for i = 0:num_st-1    % start-state i
    bin_i = dec2bin(i,num_ch);
    for j = 0:num_st-1    % end-state j
        bin_j = dec2bin(j,num_ch);
        p = 1;
        for k = 1:num_ch      
            if(bin_i(k)=='1' && bin_j(k)=='1')
                p = p * beta(k);
            elseif(bin_i(k)=='1' && bin_j(k)=='0')
                p = p * (1-beta(k));
            elseif(bin_i(k)=='0' && bin_j(k)=='0')
                p = p * (1-alpha(k));
            elseif(bin_i(k)=='0' && bin_j(k)=='1')
                p = p .* alpha(k);
            end
        end 
        fprintf(fid,'T : * : %d : %d %6.4f\n',i,j,p);
    end 
end
fprintf(fid,'\n');

% observation model
% format O : <action> : <end-state> : <observation> %f
for a = 0:num_ch-1  % action a
    for j = 0:num_st-1  % end-state j
        bin_j = dec2bin(j,num_ch);
        if(bin_j(a+1) == '0')
            fprintf(fid,'O : %d : %d : 0 1.0\n',a,j); 
            fprintf(fid,'O : %d : %d : 1 0.0\n',a,j); 
        else
            fprintf(fid,'O : %d : %d : 0 0.0\n',a,j); 
            fprintf(fid,'O : %d : %d : 1 1.0\n',a,j);
        end
    end
end
fprintf(fid,'\n');    

% reward definition
% format R : <action> : <start-state> : <end-state> : <observation> %f
fprintf(fid,'R : * : * : * : 0 0.0\n'); % no reward obtained if 0 is observed 
for a = 0:num_ch-1  % action a
    for j = 0:num_st-1  % end-state j
        bin_j = dec2bin(j,num_ch);
        if(bin_j(a+1) == '1')
            fprintf(fid,'R : %d : * : %d : 1 %6.4f\n',a,j,BW(a+1)); 
        else
            fprintf(fid,'R : %d : * : %d : 1 0.0\n',a,j);
        end
    end
end

fclose(fid);
